@@ -14,7 +14,7 @@ from sklearn import datasets, linear_model
 from napoleontoolbox.forecasting import lgbm_model_wrapper
 from napoleontoolbox.forecasting import arima_model_wrapper
 from napoleontoolbox.forecasting import sma_model_wrapper
-
+from napoleontoolbox.forecasting import simple_threshold_model_wrapper
 
 from abc import ABC, abstractmethod
 
@@ -26,7 +26,8 @@ def instantiate_model(method = 'default',idios = {}):
         return arima_model_wrapper.ArimaModel(**idios)
     if method == 'sma':
         return sma_model_wrapper.SmaModel(**idios)
-
+    if method == 'simple_threshold':
+        return simple_threshold_model_wrapper.SimpleThresholdModel(**idios)
 
 class AbstractForecasterWrapper(ABC):
     def __init__(self):
