@@ -25,7 +25,7 @@ from dateutil import parser
 
 
 class AbstractRunner(ABC):
-    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, underlying=None, frequence = None, target='target', stationarize_ohlc=False, apply_zscore=False, skipping_point=5, sentiment_grouping=False, add_bbbands=False, add_rsi_indicator=False, local_root_directory='../data/', user = 'napoleon',number_per_year=252, use_light=False, starting_iterations_to_pass=0):
+    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, underlying=None, frequence = None, target='target', stationarize_ohlc=False, apply_zscore=False, skipping_point=5, sentiment_grouping=False, add_bbbands=False, add_rsi_indicator=False, apply_binarization=False, local_root_directory='../data/', user = 'napoleon',number_per_year=252, use_light=False, starting_iterations_to_pass=0):
         super().__init__()
         self.starting_date = starting_date
         self.running_date = running_date
@@ -38,6 +38,7 @@ class AbstractRunner(ABC):
         self.skipping_point = skipping_point
         self.add_bbbands=add_bbbands
         self.add_rsi_indicator = add_rsi_indicator
+        self.apply_binarization = apply_binarization
         self.local_root_directory=local_root_directory
         self.user=user
         self.dropbox_backup = dropbox_backup
@@ -47,7 +48,7 @@ class AbstractRunner(ABC):
         self.starting_iterations_to_pass = starting_iterations_to_pass
         self.number_per_year = number_per_year
         self.use_light = use_light
-        self.predictors_file_name = 'features_'+str(self.apply_zscore)+str(self.sentiment_grouping)+str(self.add_bbbands)+str(self.add_rsi_indicator)+str(self.stationarize_ohlc)+'_set.pkl'
+        self.predictors_file_name = 'features_'+str(self.apply_zscore)+str(self.sentiment_grouping)+str(self.add_bbbands)+str(self.add_rsi_indicator)+str(self.stationarize_ohlc)+str(sel'_set.pkl'
 
 
         @abstractmethod
