@@ -591,8 +591,13 @@ class RealTimeSignalEnsemblingParalleLauncher():
         print('saving minute histo recomputation to '+backed_up_min_signal_histo_name)
         cumulated_signals.to_pickle(saving_path)
 
+        print(f'uploading to dropbox {saving_path}')
+        self.dbx.upload(fullname=saving_path, folder='', subfolder='', name=backed_up_min_signal_histo_name, overwrite=True)
+        print('done')
+
+
         self.minute_discretized_signal_np = discrete_daily_signals
-        discretized_saving_path = saving_path.replace('pkl','')
+        discretized_saving_path = saving_path.replace('pkl','napoy')
         print('saving minute histo discretized recomputation to '+discretized_saving_path)
         np.save(discretized_saving_path, self.minute_discretized_signal_np)
 
@@ -675,8 +680,14 @@ class RealTimeSignalEnsemblingParalleLauncher():
         saving_path = self.local_root_directory+backed_up_signal_histo_name
         print('saving histo recomputation to '+backed_up_signal_histo_name)
         cumulated_signals.to_pickle(saving_path)
+
+        print(f'uploading to dropbox {saving_path}')
+        self.dbx.upload(fullname=saving_path, folder='', subfolder='', name=backed_up_signal_histo_name, overwrite=True)
+        print('done')
+
         self.day_discretized_signal_np = discrete_daily_signals
-        discretized_saving_path = saving_path.replace('pkl','')
+
+        discretized_saving_path = saving_path.replace('pkl','napoy')
         print('saving day histo discretized recomputation to '+discretized_saving_path)
         np.save(discretized_saving_path, self.day_discretized_signal_np)
 
@@ -779,13 +790,17 @@ class RealTimeSignalEnsemblingParalleLauncher():
                                                                  refetch_all=True)
         return hours_df
 
-    def reload_daily_histo(self, from_cryptocompare = False,running_date = None):
+    def reload_daily_histo(self, from_cryptocompare = False,from_dropbox = True, running_date = None):
         running_date = running_date - timedelta(days=1)
         if from_cryptocompare :
             backed_up_signal_histo_name =  running_date.strftime('%d_%b_%Y')+'_'+self.underlying+'_'+self.backed_up_day_signal_histo_suffix
             saving_path = self.local_root_directory+backed_up_signal_histo_name
-            print('loading histo recomputation to '+backed_up_signal_histo_name)
-            updated_df = pd.read_pickle(saving_path)
+            if from_dropbox:
+                print(f'downloading from dropbox {backed_up_signal_histo_name}')
+                updated_df = self.dbx.download_pkl(backed_up_signal_histo_name)
+            else :
+                print(f'loading histo recomputation to  {saving_path}')
+                updated_df = pd.read_pickle(saving_path)
             updated_df=updated_df.sort_index()
             signal_columns = [self.day_signal_mapping[me_sig] for me_sig in self.day_calib_signals_list]
             me_columns = self.generic_columns + signal_columns
